#!/usr/bin/env python
# /*****************************************************************************
# * Copyright (c) [2024] ams-OSRAM AG                                          *
# * All rights are reserved.                                                   *
# *                                                                            *
# * FOR FULL LICENSE TEXT SEE LICENSE.TXT                                      *
# ******************************************************************************/
 

"""Start script for TMF8806 ZeroMQ server."""

import logging
import signal
import sys

from zeromq.tmf8x0x_linux_adapter import LinuxAdapter
from zeromq.tmf8x0x_zeromq_server import ZeroMqServer

logging.basicConfig(level=logging.INFO,
                    format='%(levelname)s %(name)s.%(funcName)s:%(lineno)d %(message)s')

server = ZeroMqServer(adapter=LinuxAdapter())
server.start(cmd_addr="tcp://169.254.0.2:5555", result_addr="tcp://169.254.0.2:5556")

def stop_server(sig, frame):
    """Stop the server and exit."""
    global server
    server.stop()
    sys.exit(0)

signal.signal(signal.SIGINT, stop_server)
signal.signal(signal.SIGTERM, stop_server)
signal.pause()
